==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleLinkSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleLinkSpecBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpec,io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecBuilder>{
  public ConsoleLinkSpecBuilder() {
    this(false);
  }
  public ConsoleLinkSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleLinkSpec(), validationEnabled);
  }
  public ConsoleLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleLinkSpec(), validationEnabled);
  }
  public ConsoleLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplicationMenu(instance.getApplicationMenu()); 
    fluent.withHref(instance.getHref()); 
    fluent.withLocation(instance.getLocation()); 
    fluent.withNamespaceDashboard(instance.getNamespaceDashboard()); 
    fluent.withText(instance.getText()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpec instance) {
    this(instance,false);
  }
  public ConsoleLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplicationMenu(instance.getApplicationMenu()); 
    this.withHref(instance.getHref()); 
    this.withLocation(instance.getLocation()); 
    this.withNamespaceDashboard(instance.getNamespaceDashboard()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleLinkSpec build() {
    ConsoleLinkSpec buildable = new ConsoleLinkSpec(fluent.getApplicationMenu(),fluent.getHref(),fluent.getLocation(),fluent.getNamespaceDashboard(),fluent.getText());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleLinkSpecBuilder that = (ConsoleLinkSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-6.3.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleLinkSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsoleLinkSpecBuilder extends ConsoleLinkSpecFluentImpl<ConsoleLinkSpecBuilder> implements VisitableBuilder<ConsoleLinkSpec,ConsoleLinkSpecBuilder>{
  public ConsoleLinkSpecBuilder() {
    this(false);
  }
  public ConsoleLinkSpecBuilder(Boolean validationEnabled) {
    this(new ConsoleLinkSpec(), validationEnabled);
  }
  public ConsoleLinkSpecBuilder(ConsoleLinkSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleLinkSpecBuilder(ConsoleLinkSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsoleLinkSpec(), validationEnabled);
  }
  public ConsoleLinkSpecBuilder(ConsoleLinkSpecFluent<?> fluent,ConsoleLinkSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleLinkSpecBuilder(ConsoleLinkSpecFluent<?> fluent,ConsoleLinkSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplicationMenu(instance.getApplicationMenu()); 
    fluent.withHref(instance.getHref()); 
    fluent.withLocation(instance.getLocation()); 
    fluent.withNamespaceDashboard(instance.getNamespaceDashboard()); 
    fluent.withText(instance.getText()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleLinkSpecBuilder(ConsoleLinkSpec instance) {
    this(instance,false);
  }
  public ConsoleLinkSpecBuilder(ConsoleLinkSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplicationMenu(instance.getApplicationMenu()); 
    this.withHref(instance.getHref()); 
    this.withLocation(instance.getLocation()); 
    this.withNamespaceDashboard(instance.getNamespaceDashboard()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConsoleLinkSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ConsoleLinkSpec build() {
    ConsoleLinkSpec buildable = new ConsoleLinkSpec(fluent.getApplicationMenu(),fluent.getHref(),fluent.getLocation(),fluent.getNamespaceDashboard(),fluent.getText());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
